==> net.bluemind.p2.platform-4.9.3879.zip: net/bluemind/mailmessage/api/gwt/endpoint/MailTipGwtEndpoint.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.mailmessage.api.gwt.endpoint;

import net.bluemind.core.api.AsyncHandler;
import net.bluemind.core.commons.gwt.EndpointRequestCallback;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;

import com.google.gwt.http.client.RequestBuilder;
import com.google.gwt.http.client.RequestException;
import com.google.gwt.json.client.JSONValue;
import java.util.List;
import java.util.Map;
import java.util.Set;
import net.bluemind.core.api.Stream;
import java.lang.Long;

public class MailTipGwtEndpoint implements net.bluemind.mailmessage.api.IMailTipAsync {

	private String baseUri;

	private String sessionId;

	private String root = "/api";

	public MailTipGwtEndpoint(String sessionId, String... pathVars) {
		String uri_ = "/mailtip/{domainUid}";
		this.sessionId = sessionId;
	
		uri_ = uri_.replace("{domainUid}",pathVars[0]);
		
		baseUri = uri_;
	}

	public MailTipGwtEndpoint withRoot(String root) {
		this.root = root;
		return this;
	}

	@Override
	public void getMailTips(net.bluemind.mailmessage.api.MailTipContext mailtipContext, final AsyncHandler<List<net.bluemind.mailmessage.api.MailTips>> handler) {
		String postUri = "";

		String uri_ = baseUri + postUri;

		String queryParams = "?";
		uri_ += queryParams;
		String bodyContent = null;
		RequestBuilder builder = new RequestBuilder(RequestBuilder.POST, root + uri_);
		builder.setHeader("X-BM-ApiKey", sessionId);
		JSONValue jsonValue = new net.bluemind.mailmessage.api.gwt.serder.MailTipContextGwtSerDer().serialize( mailtipContext);
		if( jsonValue != null) {
			bodyContent = jsonValue.toString();
		}

		builder.setHeader("Accept", "application/json");
		builder.setRequestData(bodyContent);
		builder.setCallback( new EndpointRequestCallback<List<net.bluemind.mailmessage.api.MailTips>>(handler) {
			@Override
			protected List<net.bluemind.mailmessage.api.MailTips> handleResponse(
							JSONValue jsonValue) {
				return new GwtSerDerUtils.ListSerDer<>(new net.bluemind.mailmessage.api.gwt.serder.MailTipsGwtSerDer()).deserialize( jsonValue);
			}
		});


		try {
			builder.send();
		} catch (RequestException e) {
			handler.failure(e);
		}
	}

	public net.bluemind.mailmessage.api.IMailTipPromise promiseApi() {
		return new MailTipEndpointPromise(this);
	}
}

==> net.bluemind.p2.platform-5.5.3112.zip: net/bluemind/mailmessage/api/gwt/endpoint/MailTipGwtEndpoint.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.mailmessage.api.gwt.endpoint;

import net.bluemind.core.api.AsyncHandler;
import net.bluemind.core.commons.gwt.EndpointRequestCallback;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;

import com.google.gwt.json.client.JSONValue;
import com.google.gwt.http.client.RequestBuilder;
import com.google.gwt.http.client.RequestException;
import com.google.gwt.http.client.URL;
import java.util.List;
import java.util.Map;
import java.util.Set;
import net.bluemind.core.api.Stream;
import java.lang.Long;

public class MailTipGwtEndpoint implements net.bluemind.mailmessage.api.IMailTipAsync {

	private String baseUri;

	private String sessionId;

	private String root = "/api";

	public MailTipGwtEndpoint(String sessionId, String... pathVars) {
		String uri_ = "/mailtip/{domainUid}";
		this.sessionId = sessionId;
	
		uri_ = uri_.replace("{domainUid}", URL.encodePathSegment(pathVars[0]));
		
		baseUri = uri_;
	}

	public MailTipGwtEndpoint withRoot(String root) {
		this.root = root;
		return this;
	}

	@Override
	public void getMailTips(net.bluemind.mailmessage.api.MailTipContext mailtipContext, final AsyncHandler<List<net.bluemind.mailmessage.api.MailTips>> handler) {
		String postUri = "";

		String uri_ = baseUri + postUri;

		String queryParams = "?";
		uri_ += queryParams;
		String bodyContent = null;
		RequestBuilder builder = new RequestBuilder(RequestBuilder.POST, root + uri_);
		builder.setHeader("X-BM-ApiKey", sessionId);
		JSONValue jsonValue = new net.bluemind.mailmessage.api.gwt.serder.MailTipContextGwtSerDer().serialize( mailtipContext);
		if( jsonValue != null) {
			bodyContent = jsonValue.toString();
		}

		builder.setHeader("Accept", "application/json");
		builder.setRequestData(bodyContent);
		builder.setCallback( new EndpointRequestCallback<List<net.bluemind.mailmessage.api.MailTips>>(handler) {
			@Override
			protected List<net.bluemind.mailmessage.api.MailTips> handleResponse(
							JSONValue jsonValue) {
				return new GwtSerDerUtils.ListSerDer<>(new net.bluemind.mailmessage.api.gwt.serder.MailTipsGwtSerDer()).deserialize( jsonValue);
			}
		});


		try {
			builder.send();
		} catch (RequestException e) {
			handler.failure(e);
		}
	}

	public net.bluemind.mailmessage.api.IMailTipPromise promiseApi() {
		return new MailTipEndpointPromise(this);
	}
}
